@@ -700,7 +700,7 @@ test_watch_cancels (Test *test,
 	                                           on_result_pair_two, &pair);
 
 	/* Wait a bit before stopping, so outgoing request is done */
-	g_usleep (G_TIME_SPAN_SECOND / 4);
+	egg_test_wait_until (250);
 
 	/* Kill the mock prompter */
 	gcr_mock_prompter_disconnect ();
